abacusai.workflow_graph_node_details — AbacusAI documentation

# abacusai.workflow_graph_node_details

## Classes

`WorkflowGraphNodeDetails` | A workflow graph node in the workflow graph.

## Module Contents

class abacusai.workflow_graph_node_details.WorkflowGraphNodeDetails(client, packageRequirements=None, workflowGraphNode={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A workflow graph node in the workflow graph.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - packageRequirements (list[str]) – A list of package requirements that the node source code will need.

    - workflowGraphNode (WorkflowGraphNode) – The workflow graph node object.

  package_requirements = None
  workflow_graph_node
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict